==> alone-frame-1.4.2.tgz: package/frame/app.js <==
import {global} from "alone-frame/global.js";

import storage from "alone-frame/storage.js";

import alone from "alone-frame/alone.js";

import http from "alone-frame/http.js";

import {getCurrentInstance} from "vue";

const pro = process || {}, env = pro.env || {};

export default {
    //路由对像
    route: {},
    //路由参数
    routes: [],
    //i188对像
    i18n: {},
    //配置
    config: global(env.app_ver || "app" + "_config"),
    get_env(key = null) {
        return alone.get_arr(env, key, '')
    },
    get_conf(key = null, def = null) {
        return alone.get_arr(this.config.list().conf || {}, key, def);
    },
    get_origin() {
        return storage.get('originCache');
    },
    get_make() {
        return storage.get('makeCache');
    },
    http(path) {
        return http((import.meta.env.MODE === 'preview' ? '/api' : this.get_env('api'))).path(path).cross(true);
    },
    set_title(title = '') {
        return alone.set_title(title || this.config.get('title'));
    },
    //获取和设置语言名称
    get_locale(locale = '', fallback = '') {
        if (alone.isset(locale)) {
            this.i18n.global.locale = locale;
            storage.set('langLocale', locale);
        }
        if (alone.isset(fallback)) {
            this.i18n.global.fallbackLocale = fallback;
        }
        return storage.get('langLocale', locale);
    },
    //获取语言内容
    get_lang(key, tag = {}) {
        return this.i18n.global.t(key, tag)
    },
    //设置语言
    set_lang(key, val = null, lang = '', merge = true) {
        const object = this.i18n.global;
        const value = alone.is_object(key) ? key : alone.set_arr(key, val);
        const locale = lang ? lang : this.get_locale();
        merge ? object.mergeLocaleMessage(locale, value) : object.setLocaleMessage(locale, value);
        return value;
    },
    //路由跳转
    route_path(path, {name = '', params = {}, query = {}, hash = ''} = {}) {
        this.route.push({path: path, name: name, params: params, query: query, hash: hash});
    },
    //获取路由
    get_route(key = '', def = null) {
        return alone.get_arr(this.route.currentRoute.value, key, def);
    },
    //判断路由
    is_route(val, key = 'path', type = false) {
        return this.route.getRoutes().some(record => (alone.get_arr(record, key, null) === type ? this.get_route(val) : val));
    },
    /**
     * 代替this
     * @param type
     * @returns {
     * import('vue-router').ComponentPublicInstance &
     * {
     *     $route: import('vue-router')._RouteRecordBase,
     *     $router: import('vue-router').Router,
     *     $i18n: import('vue-i18n').I18n
     * }
     * }
     */
    then(type = null) {
        const {proxy, appContext} = getCurrentInstance();
        const global = appContext?.config?.globalProperties || {};
        return ((type === null) ? proxy : (type === true ? Object.assign(proxy, global) : global));
    }
};

==> alone-frame-1.4.7.tgz: package/frame/app.js <==
import {global} from "alone-frame/global.js";

import storage from "alone-frame/storage.js";

import alone from "alone-frame/alone.js";

import http from "alone-frame/http.js";

import {getCurrentInstance} from "vue";

export default {
    //路由对像
    route: {},
    //路由参数
    routes: [],
    //i188对像
    i18n: {},
    //配置
    config: global("alone_frame_config"),
    get_env(key = null) {
        return alone.get_arr(process.env, key, '')
    },
    get_conf(key = null, def = null) {
        return alone.get_arr(this.config.list().conf || {}, key, def);
    },
    get_origin() {
        return storage.get('originCache');
    },
    get_make() {
        return storage.get('makeCache');
    },
    http(path) {
        return http((import.meta.env.MODE === 'preview' ? '/api' : this.get_env('api'))).path(path).cross(true);
    },
    set_title(title = '') {
        return alone.set_title(title || this.config.get('title'));
    },
    //获取和设置语言名称
    get_locale(locale = '', fallback = '') {
        if (alone.isset(locale)) {
            this.i18n.global.locale = locale;
            storage.set('langLocale', locale);
        }
        if (alone.isset(fallback)) {
            this.i18n.global.fallbackLocale = fallback;
        }
        return storage.get('langLocale', locale);
    },
    //获取语言内容
    get_lang(key, tag = {}) {
        return this.i18n.global.t(key, tag)
    },
    //设置语言
    set_lang(key, val = null, lang = '', merge = true) {
        const object = this.i18n.global;
        const value = alone.is_object(key) ? key : alone.set_arr(key, val);
        const locale = lang ? lang : this.get_locale();
        merge ? object.mergeLocaleMessage(locale, value) : object.setLocaleMessage(locale, value);
        return value;
    },
    //路由跳转
    route_path(path, {name = '', params = {}, query = {}, hash = ''} = {}) {
        this.route.push({path: path, name: name, params: params, query: query, hash: hash});
    },
    //获取路由
    get_route(key = '', def = null) {
        return alone.get_arr(this.route.currentRoute.value, key, def);
    },
    //判断路由
    is_route(val, key = 'path', type = false) {
        return this.route.getRoutes().some(record => (alone.get_arr(record, key, null) === type ? this.get_route(val) : val));
    },
    /**
     * 代替this
     * @param type
     * @returns {
     * import('vue-router').ComponentPublicInstance &
     * {
     *     $route: import('vue-router')._RouteRecordBase,
     *     $router: import('vue-router').Router,
     *     $i18n: import('vue-i18n').I18n
     * }
     * }
     */
    then(type = null) {
        const {proxy, appContext} = getCurrentInstance();
        const global = appContext?.config?.globalProperties || {};
        return ((type === null) ? proxy : (type === true ? Object.assign(proxy, global) : global));
    }
};
